import httpRequest from '@/utils/axios'
import type { ProjectRequestParams } from './types'

// 获取列表
export function getProjectList(params?: {
  project_id?: string
  project_type?: string
  project_status?: string
  title?: string
  page?: number
  ['per-page']?: number
}) {
  return httpRequest.get('/api/zws/v1/backend/project/list', { params })
}

// 搜索用户
export function searchUser(params: { q: string }) {
  return httpRequest.get('/api/zws/v1/backend/common/search-user', { params })
}

// 获取角色
export function getProjectRoles() {
  return httpRequest.get('/api/zws/v1/backend/common/project-roles')
}

// 创建项目
export function createProject(data: ProjectRequestParams) {
  return httpRequest.post('/api/zws/v1/backend/project/create', data)
}

// 详情
export function getProjectDetail(params: { id: string }) {
  return httpRequest.get('/api/zws/v1/backend/project/view', { params })
}

// 获取成员列表
export function getProjectUserList(params: { id: string; 'per-page'?: number; page?: number }) {
  return httpRequest.get('/api/zws/v1/backend/project/member', { params })
}

// 更新项目
export function updateProject(data: { id: string } & ProjectRequestParams) {
  return httpRequest.post('/api/zws/v1/backend/project/update', data)
}

// 获取项目相关的公共map
export function getProjectMap() {
  return httpRequest.get('/api/zws/v1/backend/project/conditions')
}

// 删除人员
export function deleteMember(data: { user_id: string; project_id: string; role_id: string }) {
  return httpRequest.post('/api/zws/v1/backend/project/member-delete', data)
}

// 新增人员
export function addMember(data: { user_id: string; projects_id: string; roles: string; type?: string }) {
  return httpRequest.post('/api/zws/v1/backend/project/member-create', data)
}

// 删除项目
export function deleteProject(data: { id: string }) {
  return httpRequest.post('/api/zws/v1/backend/project/delete', data)
}
